%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Dynare set-up:
%  SW  Model Non-linear

%   sigma_c now espressed as a function of the inverse elasticity of substitution sigma_es
%   rescaling parameter for shocks now sigma_s
%   Calibrate varrho to hit H_bar in external steady state

%   Unemployment removed
%   Indexing in ss option
%   Complete indexing in the ss as in SW

%  - With habit and indexing
%  - price and wage stickiness
%  - capacity utilization and investment shock
%  - Fixed costs in wholesale sector
%  - Non-zero ss inflation
%  - Non-zero sss growth
%  - Intertemporal Welfare 
%  - Revised Wage dynamics
%  - Note W is the real wage
%  - Empirical Monetary Rule
%  - Non-zero ss growth 

% Internal or External Habit

% Correct IS in capacity utilization
% Add risk premium and labour supply shocks
% MC and MRS shocks ARMA(1,1)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%----------------------------------------------------------------
% 0. Housekeeping (close all graphic windows)
%----------------------------------------------------------------
close all;

%----------------------------------------------------------------
% Control panel
%----------------------------------------------------------------

@#define pricesticky = 1 

% this is an option you can specify. options follow @

% pricesticky = 1 gives sticky prices
% pricesticky = 0 gives flexi prices

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@#define wagesticky = 1

% wagesticky = 1 gives sticky wages
% wagesticky = 0 gives flexi wages

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@#define priceindex = 1 
 
%priceindex = 1 gives price indexing
%priceindex = 0 gives no price indexing 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@#define wageindex = 1 

%wageindex = 1 gives wage indexing
%wageindex = 0 gives no wage indexing 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@#define capacityutil = 1 

%capacityutil = 1 gives variable capacity utilization
%capacityutil = 0 gives fixed full capacity utilization

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

@#define form_of_habits= 0

%form_of_habits= 1 gives external habit
%form_of_habits= 0 gives internal habit

@#define form_of_indexing= 1

%form_of_indexing= 1 gives indexing of wages and prices in the steady state (as in SW07)
%form_of_indexing= 0 gives no indexing of wages and prices in the steady state

%----------------------------------------------------------------
% 1. Defining variables
%----------------------------------------------------------------
%   This section defines each variable and parameters using Latex 
%   syntax so to trigger Dynare producing a .tex file with all
%   the equilibrium conditions in the .mod file

%----------------------------------------------------------------
% Declaration of endogeneous variables
%----------------------------------------------------------------


var

	U           $U$         (long_name='Utility')
    UC          $UC$        (long_name='Marginal utility of consumption')
    UH          $UH$        (long_name='Marginal utility of labour')
    LAMBDA      $\lambda$   (long_name='Stochastic discount factor')
    R           $R$         (long_name='Risk free interest rate')
    RK          $R^{K}$     (long_name='Return on capital')
    C           $C$         (long_name='Consumption') 
    CE 			$CE$		(long_name='Consumption - auxiliary variable')
    W           $W$         (long_name='Real wage')
    H           $H$         (long_name='Hours')
    Y           $Y$         (long_name='Output') 
    YW          $Y^{W}$     (long_name='Intermediate output')
    PWP         $P^{W}$     (long_name='Intermediate price')
    K           $K$         (long_name='Capital stock')
    I           $I$         (long_name='Investment') 
    
    
    
%--------------------------------------------------------------------------------
%   Variables in deviation from the steady state (used for IRFs)
%--------------------------------------------------------------------------------

    
    RR              $RR$       (long_name='Real interest rate - deviation from the steady state') 
    YY              $yy$       (long_name='Output - deviation from the steady state')
    CC              $cc$       (long_name='Consumption - deviation from the steady state') 
    HH              $hh$       (long_name='Hours - deviation from the steady state') 
    WW              $ww$       (long_name='Real wage - deviation from the steady state')
    II              $ii$       (long_name='Investment - deviation from the steady state') 
    KK              $kk$       (long_name='Capital - deviation from the steady state') 
    QQ              $qq$       (long_name='Tobin Q - deviation from the steady state')  
	RnRn 			$RnRn$     (long_name='Nominal interest rate - deviation from the steady state')
    MCMC			$MCMC$	   (long_name='Marginal cost - deviation from the steady state')
    uu				$uu$	   (long_name='Capacity utilization - deviation from the steady state')
    PIEPIE			$PIEPIE$   (long_name='Price inflation - deviation from the steady state')
    PIEwPIEw		$PIEwPIEw$ (long_name='Wage inflation - deviation from the steady state')
    
    KYW         ${\frac{\bar{K}}{\bar{YW}}}$   (long_name='Capital output ratio in steady state')
    IY          ${\frac{\bar{I}}{\bar{Y}}}$    (long_name='Investment output ratio in steady state')
    CY          ${\frac{\bar{C}}{\bar{Y}}}$    (long_name='Consumption output ratio in steady state')
    S           $S$                          (long_name='Investment adjustment costs') 
    Sdash       $S^{l}$                      (long_name='Adjustment costs on X')
    Q           $Q$                          (long_name='Tobin Q')
    X           $X$                          (long_name='Gross growth rate of investment')
    Rn          $Rn$                         (long_name='Nominal interest rate') 
    ER          $E(R)$                       (long_name='Ex-post real interest rate')
    
    PIE         $Pi$                         (long_name='Price inflation')  
    PIEtilde    $\tilde{\pi}$                (long_name='Optimal reset price') 
	PIEwtilde	$\tilde{\pi^{w}}$            (long_name='Optimal reset wage') 
    PIEwptilde	$\tilde{\pi^{wp}}$			 (long_name='Degree of wage indexation')
    
    JJp         $JJ$                        (long_name='Price setting - Recursive auxiliary variable 1a')
    Jp          $J$                         (long_name='Price setting - Recursive auxiliary variable 1b')
    Deltap      $\delta$                    (long_name='Price dispersion')
    
    Wh          $Wh$                        (long_name='Wage from the labour supply')
	PIEw       	$Pi^{w}$                    (long_name='Wage inflation')
    Jw          $Jw$                        (long_name='Wage setting - Recursive auxiliary variable 1b')
    JJw         $JJw$                       (long_name='Wage setting - Recursive auxiliary variable 1a')
    Deltaw      $\delta$                    (long_name='Wage dispersion')
 
	a           $a$							(long_name='Cost of capacity utilization') 
    u           $u$							(long_name='Intensity of capacity utilization')	
    rK          $rk$						(long_name='Marginal cost of capacity')
    F			$F$							(long_name='Fixed costs')
    
    WO 			$Wo$						(long_name='Optimal wage dynamic')
    PO 			$Po$						(long_name='Optimal price dynamics')
	
    MC 			$MC$						(long_name='Real marginal cost')
    Invmarkup  	$\zeta$						(long_name='Inverse markup')
    PROFIT  	$\Theta$					(long_name='Profit')
    OMEGA 		$\Omega$					(long_name='Belmann form - utility')
	bettag      $bg$						(long_name='Belmann form - slope')    
    
    A           $A$         				(long_name='Shock process - Production technology')
    G           $G$         				(long_name='Shock process - Government spending') 
    IS			$IS$						(long_name='Shock process - investment specific')	
    MCS			$MCS$						(long_name='Shock process - marginal cost')
    MRSS 		$MRS$						(long_name='Shock process - marginal rate of substitution')
    RS 			$RS$						(long_name='Shock process - Risk premium')	
	psi 		$\psi$						(long_name='Shock process - Labour supply')
	
	exoMCS 		$exoMCS$					(long_name='Marginal cost shock')
    exoMRSS 	$exoMRS$					(long_name='Marginal rate of substitution shock')

    varrho      ${\varrho}$            	  	(long_name='Weight on Leisure in utility') 
	gamma1      $\gamma^{1}$			    (long_name='parameter - slope of a')
	g 			$g$							(long_name='parameter - Growth rate of production technology')
 	
	
; 

%----------------------------------------------------------------
% Declaration of exogeneous variables
%----------------------------------------------------------------

varexo
    epsA        ${\epsilon^{A}}$      (long_name='Productivity shock')
    epsG        ${\epsilon^{G}}$      (long_name='Government spending shock')
    epsMCS      ${\epsilon^{MCS}}$    (long_name='Marginal cost shock')
    epsMRSS     ${\epsilon^{MRSS}}$   (long_name='Marginal rate of substitution shock')
    epsM        ${\epsilon^{M}}$      (long_name='Monetary policy shock')
    epsIS       ${\epsilon^{IS}}$     (long_name='Investment specific shock')
    epsAtrend   ${\epsilon^{AT}}$     (long_name='Productivity trend shock')
    epspsi      ${\epsilon^{\psi}}$   (long_name='Habit shock')
    epsRS       ${\epsilon^{RS}}$     (long_name='Risk premium shock')
;

%----------------------------------------------------------------
% Declaration of parameters
%----------------------------------------------------------------

parameters
    H_bar          ${\bar{H}}$                  (long_name='Hours in steady state') 
    zzeta          ${\zeta}$                    (long_name='Elasticity of substitution across products')
    alp            ${\alpha}$                   (long_name='Labour share')
	muu			   ${\muu}$                   	(long_name='Wage indexation')
    delta          ${\delta}$                   (long_name='Capital depreciation')
    phiX           ${\phi_{X}}$                 (long_name='Smoothing parameter of investment adjustment costs')

	xip            ${\xi^{p}}$                  (long_name='Calvo parameter prices')  
	xiw            ${\xi^{w}}$                  (long_name='Calvo parameter wages')  
    chi            ${\chi}$                     (long_name='habits persistence')
    gammap         ${\gamma^{p}}$               (long_name='degree of price indexation')
	gammaw		   ${\gamma^{w}}$               (long_name='degree of wage indexation')
    PIE_bar        ${\bar{\pi}}$                (long_name='Inflation in steady state')
	g_bar		   ${\bar{g}}$				    (long_name='Growth rate of production technology in ss')
    betta          ${\beta}$                    (long_name='Discount factor') 
	sigma_es	   ${\sigma_{es}}$				(long_name='inverse elasticity of substitution')

    rhoA           ${\rho_{A}}$                 (long_name='Persistence of labor augmentig shock')
    rhoG           ${\rho_{G}}$                 (long_name='Persistence of government spending shock')
	rhoMCS		   ${\rho^{MCS}}$    			(long_name='Persistence of marginal cost shock')
	rhoMRSS		   ${\rho^{MRSS}}$   			(long_name='Persistence of marginal rate of substitution shock')
	rhoIS 		   ${\rho^{IS}}$     			(long_name='Persistence of investment specific shock')
	rhopsi 		   ${\rho^{\psi}}$   			(long_name='Persistebce of habit shock')
	rhoRS 		   ${\rho^{RS}}$     			(long_name='Persistence of risk premium shock')

	theta_pi       ${\theta^{\pi}}$              (long_name='Taylor rule parameter for inflation')
    theta_y        ${\theta^{y}}$                (long_name='Taylor rule parameter for output') 
	theta_dy       ${\theta^{dy}}$               (long_name='Taylor rule parameter for output growth')
    rho_r          ${\rho_{R}}$                 (long_name='Interest rate smoothing parameter') 

    cy             ${cy}$                       (long_name='Consumption output ratio in steady state')
    iy             ${iy}$                       (long_name='Investment output ratio in steady state') 
    gy             ${gy}$                       (long_name='Government spending output ratio in steady state') 
	mu_p 		   ${\muu^{p}}$					(long_name='Standard deviation - marginal cost shock')
	mu_w 		   ${\muu^{w}}$					(long_name='Standard deviation- marginal rate of substitution shock')
	phi			   ${\phi}$                     (long_name='Parameter ruling gamma1 (slope of capacity utilization cost)') 
    sigma_c        ${\sigma_{C}}$               (long_name='Inverse of the elasticity of substitution')

	hab			   $hab$						(long_name='Switch for internal or external habit')
	index 		   $index$						(long_name='Switch for wage indexation in ss')
	sigma_s 	   ${\sigma_{s}}$				(long_name='Parameter for scaling shocks')

; 

%----------------------------------------------------------------
% 2. Calibration
%----------------------------------------------------------------


@#if  form_of_habits==1
		hab=1;	%	external habit
	@#else
	hab=0; 		% internal habit 
@#endif

@#if  form_of_indexing==1
		index=1; % indexing of wages and prices in the steady state (as in SW07)
	@#else 
	index=0; 	 % indexing of wages and prices in the steady state
@#endif

PIE_bar=1.004; 	 % Steady state inflation
%PIE_bar=1.00;  
g_bar=0.004;   	 % Steady state inflation growth rate of production technology
%g_bar=0;
H_bar=0.33;		% Steady state hours
chi=0.7;		% Habit parameter
muu=3;			% Wage indexation
cy=0.6; 		% Consumption output ratio
iy=0.2; 		% investment output ratio
gy=0.2; 		% Government spending output ratio
alp=0.70;       % Labour share
betta=0.99;     % Discount factor
sigma_es=1.5;	% Inverse elasticity of substitution
delta=0.025;	% Capital depreciation
phiX=2.0;		% Smoothing parameter of investment adjustment costs
phi=0.1;		% Parameter ruling gamma1 (slope of capacity utilization cost)+
				% beta distribution centred on 0.5
zzeta=7;		% Elasticity of substitution across products


%
%shock persistence
%
rhoA=0.75; 		% Persistence of labor augmentig shock
rhoG=0.75;		% Persistence of government spending shock
rhoMCS=0.75;	% Persistence of marginal cost shock
rhoMRSS=0.75;	% Persistence of marginal rate of substitution shock
rhoIS=0.75;		% Persistence of investment specific shock
rhopsi=0.75;	% Persistebce of habit shock
rhoRS=0.75;		% Persistence of risk premium shock
mu_p=0.5;		% Standard deviation of marginal cost shock
mu_w=0.5;		% Standard deviation of risk premium shock

% the following is due to the option set above. So the code is an if-else clause
% and acts acording to the above specified set up
@#if pricesticky > 0
		xip=0.75;
	@#else
	xip=0;
	zzeta=10000;
@#endif

@#if wagesticky >0
		xiw=0.75;
	@#else
	xiw=0;
	muu=10000;
@#endif

@#if priceindex > 0
		gammap=0.5;
	@#else
	gammap=0;
@#endif

@#if wageindex > 0
		gammaw=0.5;
	@#else
	gammaw=0;
@#endif


%----------------------------------------------------------------
% Monetary Policy Rule
%----------------------------------------------------------------

rho_r=0.75;
theta_pi=1.5;
theta_y=0.3;
theta_dy=0.3;

%scale sd of shocks;

sigma_s=1.0;  % 1 for irfs and order 1; 
			  % 0.01 for second oments and order 2  
%-------------------------------------------------------------------

%----------------------------------------------------------------
% 3. Model
%----------------------------------------------------------------

model;

	[name='Exogenous shock to marginal costs']
	
		exoMCS=epsMCS;

	[name='Exogenous shock to marginal elasticity of substitution']
	
		exoMRSS=epsMRSS;

	[name='Growth in A']

		log(1+g)=log(1+g_bar)+epsAtrend;

	[name='Parameter - slope of a']
	
		gamma1=STEADY_STATE(rK);
	
	[name='Parameter - Weight on Leisure in utility']
	
		varrho=STEADY_STATE(varrho);

		%sigma_c=STEADY_STATE(sigma_c);

	[name='Single period utility']

		U=((((C-chi*C(-1)/(1+g))^(1-varrho))*((1-psi*H)^varrho))^(1-sigma_c)-1)/(1-sigma_c);

	[name='Consumption - auxiliary variable']

		CE=(((1.01*(C-chi*C(-1)/(1+g)))^(1-varrho)*(1-psi*H)^varrho)^(1-sigma_c)-1)/(1-sigma_c)-U;

%-------------------------------------------------------------------------------
% Marginal utilities of consumption and hours with external or internal habit
%-------------------------------------------------------------------------------

@#if  form_of_habits==1
    % external habit

    [name='Marginal Utility of Consumption (with external habits)']
	
		UC=(1-varrho)*((C-chi*C(-1)/(1+g))^((1-varrho)*(1-sigma_c)-1))*((1-psi*H)^(varrho*(1-sigma_c)));
	
	@#else  
    [name='Marginal Utility of Consumption (with internal habits)']
    % eqn 9
	
		UC=((1-varrho)*((C-chi*C(-1)/(1+g))^((1-varrho)*(1-sigma_c)-1))*((1-psi*H)^(varrho*(1-sigma_c)))
		-betta*chi*(1-varrho)*(((1+g(+1))*C(+1)-chi*C)^((1-varrho)*(1-sigma_c)-1))*((1-H(+1)*psi(+1))^(varrho*(1-sigma_c))));

@#endif

    [name='Marginal Utility of Labour (with internal habits)']

		UH=-varrho*((C-chi*C(-1)/(1+g))^((1-varrho)*(1-sigma_c)))*((1-psi*H)^(varrho*(1-sigma_c)-1));

    [name='Belmann form - slope']

		bettag=betta*(1+g)^((1-varrho)*(1-sigma_c)-1);

	[name='Belmann form - intertemporal utility']

		OMEGA=(1-bettag)*U+bettag*OMEGA(+1);

		
%------------------------------------------------------------------------		
%	Euler equation
%-----------------------------------------------------------------------

% Risky Bonds; Rn set in period t to yield interest over period t+1, 
% ex post real interest rate R now risky

   %----------------------------------------------------------------
   % Stochastic discount factor
   %----------------------------------------------------------------

	[name='Stochastic discount factor - 1']
 
		LAMBDA=bettag*UC/UC(-1);

	[name='Stochastic discount factor - 2']
		
		R(+1)*RS*LAMBDA(+1)=1;

	%For NK: Fisher Equation

    [name='Fisher equation - real interest rate']    
    
		R=Rn(-1)/PIE;

    [name='Fisher equation - expected real interest rate']        
		
		ER=Rn/PIE(+1);

    [name='Labor Supply FOC'] 
    % eqn 17

		UH/UC=-Wh;


%------------------------------------------------------------
% Wholesale and retail sector relation
%------------------------------------------------------------

    [name='Fixed costs']
		
		F=STEADY_STATE(F);

    [name='Profits']
		
		PROFIT=Y-MC*YW;

%------------------------------------------------------------
% Production Function 
%------------------------------------------------------------

% Note: Capital stock is end-of-period

	[name='Prodution function']

		YW=((A*H/Deltaw)^alp)*(u*K(-1)/(1+g))^(1-alp);

	[name='Ratio between prodution and price dispertion']
	
		Y=(YW-F)/Deltap;



%------------------------------------------------------------
% Wholesale firms FOCs %%
%------------------------------------------------------------


	[name='Wholesale firms FOC - 1a']
	
		RK=(rK+(1-delta)*Q)/Q(-1); % gross return and MPK (rental rate)

	[name='Wholesale firms FOC - 1B']
	
		(rK*K(-1)/(1+g))/(PWP*YW)=(1-alp);

	[name='Wholesale firms FOC - 1C']
		
		IS*Q*(1-S-X*Sdash)+LAMBDA(+1)*IS(+1)*Q(+1)*Sdash(+1)*X(+1)^2=1; % where Tobin's Q is given by

	[name='Wholesale firms FOC - 2']
	
		LAMBDA(+1)*RK(+1)=1;

    [name='Wholesale firms FOC - 3']

		W*H/(Deltaw*PWP*YW)=alp; % labour demand - eqn 22

    [name='Resource constraint']
    
		Y=C+G+I +a*K(-1)/((1+g)*IS);

    [name='Capacity utilization']
	
	@#if capacityutil > 0
		gamma1+phi/(1-phi)*(u-1)=rK;
	
	[name='Cost of increasing capacity']
	
		a=gamma1*(u-1)+phi/(1-phi)/2*(u-1)^2;
	@#else
	
	u=1;

    [name='Cost of capacity utilization']

		a=0;
	@#endif

    [name='Capital law of motion']

	K=(1-S)*I*IS+(1-delta)*K(-1)/(1+g); % eqn 26

	[name='Gross growth rate of investment']

	X=I*(1+g)/I(-1);

    [name='Investment adjustment cost - 1']


	S=phiX*(X-1-g)^2;

    [name='Investment adjustment cost - 2']

	Sdash=2*phiX*(X-1-g);

%----------------------------------------------------------
% Price Inflation Dynamics and Price Dispersion
%----------------------------------------------------------

    [name='Inflation dynamic - 1']

		JJp-xip*LAMBDA(+1)*PIEtilde(+1)^(zzeta-1)*JJp(+1)*(1+g(+1))=Y;

    [name='Inflation dynamic - 2']

		Jp-xip*LAMBDA(+1)*PIEtilde(+1)^zzeta*Jp(+1)*(1+g(+1))=(1/(1-1/zzeta))*Y*MC*MCS;

	[name='Inflation dynamic - 3']

	@# if form_of_indexing ==1
		PIEtilde=(PIE/PIE(-1)^gammap)/STEADY_STATE(PIE)^(1-gammap);% Complete indexing in ss
	@#else
		PIEtilde=(PIE/PIE(-1)^gammap);% No indexing in ss
	@#endif

    [name='Inflation dynamic - 4']

	PO=Jp/JJp;

    [name='Inflation dynamic - 5']
	
	1=xip*PIEtilde^(zzeta-1)+(1-xip)*(PO)^(1-zzeta);

    [name='Inflation dynamic - 6']

	Deltap=xip*(PIEtilde^zzeta)*Deltap(-1)+(1-xip)*PO^(-zzeta);

%--------------------------------------------------------------
% Wage Inflation Dynamics and Wage Dispersion 36-38
%-----------------------------------------------------------------


	@#if wagesticky > 0

	[name='Wage inflation dynamic - 1']
	
		PIEw=PIE*W/W(-1);

		@# if form_of_indexing ==1

			[name='Wage inflation dynamic - 2']

				PIEwtilde=PIEw/PIE(-1)^gammaw/STEADY_STATE(PIE)^(1-gammaw);%Complete indexing in ss;

			[name='Wage inflation dynamic - 3']

				PIEwptilde=PIE/PIE(-1)^gammaw/STEADY_STATE(PIE)^(1-gammaw);%Complete indexing in ss;

			@#else

				[name='Wage inflation dynamic - 2']
		
					PIEwtilde=PIEw/PIE(-1)^gammaw;%no indexing in ss;

					[name='Wage inflation dynamic - 3']

					PIEwptilde=PIE/PIE(-1)^gammaw;%no indexing in ss;
			@#endif

		[name='Wage inflation dynamic - 4']

				JJw-xiw*LAMBDA(+1)*PIEwtilde(+1)^(muu)/PIEwptilde(+1)*JJw(+1)=H;

			[name='Wage inflation dynamic - 5']

				Jw-xiw*LAMBDA(+1)*PIEwtilde(+1)^muu*Jw(+1)=(1/(1-1/muu))*H*Wh*MRSS;

			[name='Wage inflation dynamic - 6']

				WO=Jw/(W*JJw); % relative wage =W_t^0/W_{n,t} in notes corresponding to relative price PO=P_t^O/P_t for prices

		[name='Wage inflation dynamic - 7']

				1=xiw*(PIEw*PIEwptilde/PIE)^(muu-1)+(1-xiw)*WO^(1-muu); 

		[name='Wage dispersion']
	
				Deltaw=xiw*(PIEwtilde^muu)*Deltaw(-1)+(1-xiw)*WO^(-muu);

		[name='Inverse markup']

				Invmarkup=Wh/W;

		@#else
		
    [name='Wage inflation dynamic - 1']

			PIEw=PIE*W/W(-1);

    [name='Wage inflation dynamic - 4']

			JJw=H;
		
    [name='Wage inflation dynamic - 5']
	
			Jw=(1/(1-(1/muu)))*H*Wh*MRSS;

    [name='Wage inflation dynamic - 6']
	
			PIEwtilde=PIEw/PIE(-1)^gammaw/STEADY_STATE(PIE)^(1-gammaw);%Complete indexing in ss;

    [name='Wage inflation dynamic - 7']
			
			PIEwptilde=PIE/PIE(-1)^gammaw/STEADY_STATE(PIE)^(1-gammaw);%Complete indexing in ss;

			%PIEwtilde=PIEw/PIE(-1)^gammaw;%No indexing in ss;
			%PIEwptilde=PIE/PIE(-1)^gammaw;%No indexing in ss;

		[name='Real wage']

			W=(1/(1-(1/muu)))*Wh*MRSS;

	[name='Wage dispersion']

			Deltaw=1;

	[name='Optimal reset wage']
			
			WO=Jw/(W*JJw);

    [name='Inverse markup']
		
			Invmarkup=Wh/W;
@#endif


    [name='Taylor rule - implementable rule (relative to ss)']

		log(Rn/STEADY_STATE(Rn))=rho_r*log(Rn(-1)/STEADY_STATE(Rn))+(1-rho_r)*(theta_pi*log(PIE/STEADY_STATE(PIE))
		+theta_y*log(Y/STEADY_STATE(Y))+theta_dy*(log(Y/STEADY_STATE(Y))-log(Y(-1)/STEADY_STATE(Y))))+epsM;


    [name='Mark-up Monopolistic pricing']


		MC=PWP;


%-----------------------------------------------
% Shock processes
%-----------------------------------------------

    [name='Productivity shock process']

		log(A)-log(STEADY_STATE(A))=rhoA*(log(A(-1))-log(STEADY_STATE(A)))+epsA;

    [name='Government shock process']

		log(G)-log(STEADY_STATE(G))=rhoG*(log(G(-1))-log(STEADY_STATE(G)))+epsG;

	  [name='Marginal cost shock process']
	
		log(MCS)-log(STEADY_STATE(MCS))=rhoMCS*(log(MCS(-1))-log(STEADY_STATE(MCS)))+epsMCS -mu_p*exoMCS(-1);

	  [name='Elasticity of substitution shock process']

		log(MRSS)-log(STEADY_STATE(MRSS))=rhoMRSS*(log(MRSS(-1))-log(STEADY_STATE(MRSS)))+epsMRSS -mu_w*exoMRSS(-1);

      [name='Investment specific shock process']

		log(IS)-log(STEADY_STATE(IS))=rhoIS*(log(IS(-1))-log(STEADY_STATE(IS)))+epsIS;

	  [name='Risk premium shock process']

		log(RS)-log(STEADY_STATE(RS))=rhoRS*(log(RS(-1))-log(STEADY_STATE(RS)))+epsRS;

	  [name='Labour supply shock process']

		log(psi)-log(STEADY_STATE(psi))=rhopsi*(log(psi(-1))-log(STEADY_STATE(psi)))+epspsi;

%----------------------------------------------------------------
% Variables in deviation form for IRFs
%----------------------------------------------------------------

YY=Y/STEADY_STATE(Y);
KK=K/STEADY_STATE(K);
II=I/STEADY_STATE(I);
CC=C/STEADY_STATE(C);
WW=W/STEADY_STATE(W);
HH=H/STEADY_STATE(H);
QQ=Q/STEADY_STATE(Q);
RR=R/STEADY_STATE(R);
RnRn=Rn/STEADY_STATE(Rn);
MCMC=MC/STEADY_STATE(MC);
PIEPIE=PIE/STEADY_STATE(PIE);
PIEwPIEw=PIEw/STEADY_STATE(PIEw);
uu=u/STEADY_STATE(u);

%----------------------------------------------------------------
% Ratio variables used in steady state
%----------------------------------------------------------------

	KYW=K/YW;
	IY=I/Y;
	CY=C/Y;
end;


steady;
check;

%----------------------------------------------------------------
% Specification of shocks
%----------------------------------------------------------------

shocks;
var epsAtrend; stderr 0.1*sigma_s;
var epsA; stderr 1*sigma_s;
var epsG; stderr 1*sigma_s;
var epsMCS; stderr 1*sigma_s;
var epsMRSS; stderr 1*sigma_s;
var epsM; stderr 0.1*sigma_s;
var epsIS; stderr 1*sigma_s;
var epsRS; stderr 0.1*sigma_s;
var epspsi; stderr 1*sigma_s;

end;


stoch_simul(order=1,irf=40,tex)  YY CC II HH WW RR QQ RnRn MCMC PIEPIE PIEwPIEw uu OMEGA ER;
%stoch_simul(order=2,pruning, irf=40, tex)  YY CC II HH WW RR QQ RnRn MCMC PIEPIE PIEwPIEw uu OMEGA ER;

write_latex_dynamic_model;
write_latex_static_model;
write_latex_definitions;
write_latex_parameter_table;
collect_latex_files;